pub struct DeviceId(/* private fields */);Expand description
Identifier of an input device.
Whenever you receive an event arising from a particular input device, this event contains a DeviceId which
identifies its origin. Note that devices may be virtual (representing an on-screen cursor and keyboard focus) or
physical. Virtual devices typically aggregate inputs from multiple physical devices.
Implementations
Sourceimpl DeviceId
impl DeviceId
Sourcepub unsafe fn dummy() -> Self
pub unsafe fn dummy() -> Self
Returns a dummy DeviceId, useful for unit testing. The only guarantee made about the return
value of this function is that it will always be equal to itself and to future values returned
by this function. No other guarantees are made. This may be equal to a real DeviceId.
Passing this into a winit function will result in undefined behavior.