ModifiersState

Struct ModifiersState 

pub struct ModifiersState { /* private fields */ }
Represents the current state of the keyboard modifiers

Each flag represents a modifier and is set if this modifier is active.

Implementations

Source

impl ModifiersState

pub fn shift(&self) -> bool

Returns true if the shift key is pressed.

pub fn ctrl(&self) -> bool

Returns true if the control key is pressed.

pub fn alt(&self) -> bool

Returns true if the alt key is pressed.

Returns true if the logo key is pressed.

Source

impl ModifiersState

pub const SHIFT: ModifiersState

The “shift” key.

pub const CTRL: ModifiersState

The “control” key.

pub const ALT: ModifiersState

The “alt” key.

This is the “windows” key on PC and “command” key on Mac.

pub const fn empty() -> ModifiersState

Returns an empty set of flags

pub const fn all() -> ModifiersState

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<ModifiersState>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> ModifiersState

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> ModifiersState

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: ModifiersState) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: ModifiersState) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: ModifiersState)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: ModifiersState)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: ModifiersState)

Toggles the specified flags in-place.

pub fn set(&mut self, other: ModifiersState, value: bool)

Inserts or removes the specified flags depending on the passed value.