The EventLoop struct and assorted supporting types, including ControlFlow.
If you want to send custom events to the event loop, use EventLoop::create_proxy()
to acquire an EventLoopProxy and call its send_event method.
See the root-level documentation for information on how to create and use an event loop to handle events.
Structs
- Event
Loop - Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
- Event
Loop Closed - The error that is returned when an
EventLoopProxyattempts to wake up anEventLoopthat no longer exists. Contains the original event given tosend_event. - Event
Loop Proxy - Used to send custom events to
EventLoop. - Event
Loop Window Target - Target that associates windows with an
EventLoop.
Enums
- Control
Flow - Set by the user callback given to the
EventLoop::runmethod.